/*  DATABASE INPUT VERIFICATION:                                     */
/*                                                                   */
/*     Determines type of database input file (*.del or *.asc).      */
/*     Reads the input data as appropriate to that file type.        */
/*     Verifies EMP_NO and DEPT_NO are numeric, names are cap alpha. */

arg input_file .                   /* read input file name from user */
c = ','                            /* variable C contains one comma  */

do while lines(input_file) > 0
   input_line = linein(input_file)    /* read a line from input file */

   /* get EMP_NO, FNAME, LNAME, DEPT_NO from *.DEL or *.ASC file     */ 

   if pos(c,input_line) > 0 then do       /* file is delimited ascii */
      parse value input_line with emp_no (c) fname (c) lname (c) dept_no
      fname   = strip(fname,B,'"')
      lname   = strip(lname,B,'"')        /* remove quote " marks    */
      dept_no = strip(dept_no,,'"')
      end
   else do       
      parse value input_line with emp_no 6 fname 13 lname 20 dept_no
      fname   = strip(fname)
      lname   = strip(lname)              /* remove trailing blanks  */
   end

   say 'Input line:' emp_no fname lname dept_no

   /* Ensure EMP_NO & DEPT_NO are numeric */
   
   if datatype(emp_no) \= 'NUM'  |  datatype(dept_no) \= 'NUM' then
      say 'EMP_NO or DEPT_NO are not numeric:' emp_no dept_no
   
   /* Ensure the two names start with a capital letter */

   if verify(substr(fname,1,1),'ABCDEFGHIJKLMNOPQRSTUVWXYZ') > 0 then
      say "First name doesn't start with a capital letter:" fname
   if verify(substr(lname,1,1),'ABCDEFGHIJKLMNOPQRSTUVWXYZ') > 0 then
      say "Last name doesn't start with a capital letter:" lname

end


